@@ -4,7 +4,6 @@
 #pragma once
 
 #include "common/Pcsx2Defs.h"
-#include "common/VectorIntrin.h"
 
 // For multiple-isa compilation
 #ifdef MULTI_ISA_UNSHARED_COMPILATION
@@ -45,9 +44,10 @@
 struct ProcessorFeatures
 {
 #ifdef _M_X86
-	enum class VectorISA { SSE4, AVX, AVX2 };
+	enum class VectorISA { SSE4, AVX, AVX2, AVX512F };
 	VectorISA vectorISA;
 	bool hasFMA;
+	bool hasBMI2;
 	bool hasSlowGather;
 #endif
 };
